using System;
using System.Web.UI.WebControls;
using Microsoft.SharePoint.WebControls;

namespace AndrewConnell.SharePoint.CustomFields {
  public class FieldCollegeFootballTeamControl : BaseFieldControl {
    const string RENDERING_TEMPLATE_NAME = "FieldCollegeFootballTeamRendering";

    protected TextBox txbSchoolName;
    protected TextBox txbSchoolMascot;

    protected override string DefaultTemplateName {
      get {
        return RENDERING_TEMPLATE_NAME;
      }
    }

    public override void Focus () {
      EnsureChildControls();
      txbSchoolName.Focus();
    }

    protected override void CreateChildControls () {
      if (Field == null)
        return;

      
      base.CreateChildControls();


      // if in display mode, don't show controls
      if (this.ControlMode == SPControlMode.Display) return;


      // build input controls
      txbSchoolName = (TextBox)TemplateContainer.FindControl("SchoolName");
      if (txbSchoolName == null)
        throw new ArgumentException("SchoolName TextBox not found (possibly corrupt control template).");
      txbSchoolName.CssClass = this.CssClass;

      txbSchoolMascot = (TextBox)TemplateContainer.FindControl("SchoolMascot");
      if (txbSchoolMascot == null)
        throw new ArgumentException("SchoolMascot TextBox field not found (possibly corrupt control template).");
      txbSchoolMascot.CssClass = this.CssClass;
    

      // if it's a new form, insert default info
      if (this.ControlMode == SPControlMode.New) {
        this.txbSchoolName.Text = Field.GetCustomProperty("DefaultSchoolName").ToString().Trim();
        this.txbSchoolMascot.Text = Field.GetCustomProperty("DefaultSchoolMascot").ToString().Trim();
      }
    }

    public override object Value {
      get {
        EnsureChildControls();

        FieldCollegeFootballTeamValue fieldValue = new FieldCollegeFootballTeamValue();
        fieldValue.SchoolName = txbSchoolName.Text.Trim();
        fieldValue.SchoolMascot = txbSchoolMascot.Text.Trim();

        return fieldValue;
      }
      set {
        EnsureChildControls();

        FieldCollegeFootballTeamValue fieldValue = new FieldCollegeFootballTeamValue();
        txbSchoolName.Text = fieldValue.SchoolName;
        txbSchoolMascot.Text = fieldValue.SchoolMascot;
      }
    }
  }
}
